==> Paws-0.25.tar.gz: Paws-0.25/lib/Paws/IoT/DescribeCACertificate.pm <==

package Paws::IoT::DescribeCACertificate;
  use Moose;
  has CertificateId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'certificateId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCACertificate');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/cacertificate/{certificateId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::DescribeCACertificateResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::DescribeCACertificate - Arguments for method DescribeCACertificate on Paws::IoT

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCACertificate on the 
AWS IoT service. Use the attributes of this class
as arguments to method DescribeCACertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCACertificate.

As an example:

  $service_obj->DescribeCACertificate(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> CertificateId => Str

The CA certificate identifier.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCACertificate in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.27.tar.gz: Paws-0.27/lib/Paws/IoT/DescribeCACertificate.pm <==

package Paws::IoT::DescribeCACertificate;
  use Moose;
  has CertificateId => (is => 'ro', isa => 'Str', traits => ['ParamInURI'], uri_name => 'certificateId' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DescribeCACertificate');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/cacertificate/{caCertificateId}');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::DescribeCACertificateResponse');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::DescribeCACertificate - Arguments for method DescribeCACertificate on Paws::IoT

=head1 DESCRIPTION

This class represents the parameters used for calling the method DescribeCACertificate on the 
AWS IoT service. Use the attributes of this class
as arguments to method DescribeCACertificate.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DescribeCACertificate.

As an example:

  $service_obj->DescribeCACertificate(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> CertificateId => Str

The CA certificate identifier.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DescribeCACertificate in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
